utils.specutils_cos package
===========================

check_segments
-----------------------------------------

.. automodule:: utils.specutils_cos.check_segments
    :members:
    :undoc-members:
    :show-inheritance:

cosspectrum
--------------------------------------

.. automodule:: utils.specutils_cos.cosspectrum
    :members:
    :undoc-members:
    :show-inheritance:

extract_subspec
------------------------------------------

.. automodule:: utils.specutils_cos.extract_subspec
    :members:
    :undoc-members:
    :show-inheritance:

get_segment_names
--------------------------------------------

.. automodule:: utils.specutils_cos.get_segment_names
    :members:
    :undoc-members:
    :show-inheritance:

plotspec
-----------------------------------

.. autofunction:: utils.specutils_cos.plotspec

readspec
-----------------------------------

.. autofunction:: utils.specutils_cos.readspec
